# Basscss

Low-level CSS toolkit – the original [Functional CSS][functional-css] library <http://basscss.com>

[![Build Status](https://travis-ci.org/basscss/basscss.svg)](https://travis-ci.org/basscss/basscss)
[![npm version](https://badge.fury.io/js/basscss.svg)](https://badge.fury.io/js/basscss)

## Lightning-Fast Modular CSS with No Side Effects

Basscss is a lightweight collection of immutable utilities designed for speed, clarity, performance, and scalability.

## Stable

Basscss v8 is the final version of Basscss, which means no major, breaking changes will be introduced.
Minor features and patches may be added, but
due to the nature of this CSS approach, there are virtually no bugs in Basscss.

---

## Features

### Code with Confidence

Using clear, humanized naming conventions, Basscss is quick to internalize
and easy to reason about while speeding up development time with more scalable,
more readable code.

### No Side Effects

Things behave exactly as expected with immutable utilities
and styles that follow the open/closed principle
to help prevent common pitfalls with CSS.

### Composable

Reusable, interoperable styles
work like building blocks to lay the foundation for any stylesheet
and can be mixed and matched in any number of combinations.

## Designed for Design

Basscss strikes a balance between consistency and flexibility
to allow for rapid prototyping and quick iterative changes
when designing in the browser.

## Responsive by Default

Basscss provides lightweight, performant styles
and flexible utilities to design for any device
and to help reduce boilerplate in stylesheets.

## Unassuming

Modular and customizable typography and layout styles don’t dictate
what things should look like and play well with other stylesheets and frameworks.

[Read More](http://basscss.com)

---

## Other Packages

### Base styles

The core Basscss package does not include any base element styles.
For an out-of-the-box solution, see:

https://github.com/basscss/basic

### Addons

In addition to the core modules, optional modules,
including responsive margin, padding, layout, and typography styles, can be found here:

https://github.com/basscss/addons

### Ace.css

For a bundle with the core Basscss and all optional modules, see:

https://github.com/basscss/ace

---

## Contributing

See [CONTRIBUTING.md](CONTRIBUTING.md)

## Related

- [Tachyons][tachyons]
- [Buzzfeed Solid][solid]
- [OOCSS][oocss]

## Thanks

This library was largely inspired and influenced by the following people

- [Nicole Sullivan](https://twitter.com/stubbornella)
- [Nicolas Gallagher](https://twitter.com/necolas)
- [Adam Morse](https://twitter.com/mrmrs_)
- [Jessica Harllee](https://twitter.com/harllee)
- [Zack Sears](https://twitter.com/zacksears)
- [Diana Mounter](https://twitter.com/broccolini)
- [John Otander](https://twitter.com/4lpine)

---

[MIT license](LICENSE.md)

[functional-css]: https://jon.gold/2015/07/functional-css/
[tachyons]: http://tachyons.io
[solid]: https://solid.buzzfeed.com
[oocss]: https://github.com/stubbornella/oocss/wiki
